@@ -1,4 +1,4 @@
-/* $Id: android_dev.c 5138 2015-07-30 06:23:35Z ming $ */
+/* $Id: android_dev.c 5544 2017-01-24 05:41:05Z nanang $ */
 /*
  * Copyright (C) 2015 Teluu Inc. (http://www.teluu.com)
  *
@@ -71,6 +71,7 @@ typedef struct and_dev_info
 {
     pjmedia_vid_dev_info	 info;		/**< Base info         */
     unsigned			 dev_idx;	/**< Original dev ID   */
+    pj_bool_t			 facing;	/**< Front/back camera?*/
     unsigned			 sup_size_cnt;	/**< # of supp'd size  */
     pjmedia_rect_size		*sup_size;	/**< Supported size    */
     unsigned			 sup_fps_cnt;	/**< # of supp'd FPS   */
@@ -525,6 +526,7 @@ static pj_status_t and_factory_refresh(pjmedia_vid_dev_factory *ff)
 
 	/* Set driver & name info */
 	pj_ansi_strncpy(vdi->driver, "Android", sizeof(vdi->driver));
+	adi->facing = facing;
 	if (facing == 0) {
 	    pj_ansi_strncpy(vdi->name, "Back camera", sizeof(vdi->name));
 	} else {
@@ -748,7 +750,7 @@ static pj_status_t and_factory_create_stream(
     const pjmedia_video_format_detail *vfd;
     const pjmedia_video_format_info *vfi;
     pjmedia_video_apply_fmt_param vafp;
-    pj_uint32_t and_fmt;
+    pj_uint32_t and_fmt = 0;
     unsigned convert_to_i420 = 0;
     pj_status_t status = PJ_SUCCESS;
 
@@ -953,6 +955,10 @@ static pj_status_t and_stream_set_cap(pjmedia_vid_dev_stream *s,
 		status = PJMEDIA_EVID_SYSERR;
 	    } else {
 		strm->param.cap_id = p->target_id;
+		
+		/* If successful, set the orientation as well */
+		and_stream_set_cap(s, PJMEDIA_VID_DEV_CAP_ORIENTATION,
+            		       	   &strm->param.orient);
 	    }
 	    jni_detach_env(with_attach);
 	    break;
@@ -961,6 +967,8 @@ static pj_status_t and_stream_set_cap(pjmedia_vid_dev_stream *s,
         case PJMEDIA_VID_DEV_CAP_ORIENTATION:
         {
             pjmedia_orient orient = *(pjmedia_orient *)pval;
+            pjmedia_orient eff_ori;
+            and_dev_info *adi;
 
 	    pj_assert(orient >= PJMEDIA_ORIENT_UNKNOWN &&
 	              orient <= PJMEDIA_ORIENT_ROTATE_270DEG);
@@ -984,7 +992,16 @@ static pj_status_t and_stream_set_cap(pjmedia_vid_dev_stream *s,
 	    	    return status;
 	    }
 	    
-	    pjmedia_vid_dev_conv_set_rotation(&strm->conv, strm->param.orient);
+	    eff_ori = strm->param.orient;
+	    adi = &strm->factory->dev_info[strm->param.cap_id];
+	    /* Normalize the orientation for back-facing camera */
+	    if (!adi->facing) {
+		if (eff_ori == PJMEDIA_ORIENT_ROTATE_90DEG)
+		    eff_ori = PJMEDIA_ORIENT_ROTATE_270DEG;
+		else if (eff_ori == PJMEDIA_ORIENT_ROTATE_270DEG)
+		    eff_ori = PJMEDIA_ORIENT_ROTATE_90DEG;
+	    }
+	    pjmedia_vid_dev_conv_set_rotation(&strm->conv, eff_ori);
 	    
 	    PJ_LOG(4, (THIS_FILE, "Video capture orientation set to %d",
 	    			  strm->param.orient));
@@ -1090,12 +1107,12 @@ static void JNICALL OnGetFrame(JNIEnv *env, jobject obj,
                                jbyteArray data, jint length,
 			       jlong user_data)
 {
-    and_stream *strm = *(and_stream**)&user_data;
+    and_stream *strm = (and_stream*)(intptr_t)user_data;
     pjmedia_frame f;
     pj_uint8_t *Y, *U, *V;
     pj_status_t status; 
-    void *frame_buf, *data_buf;     
-
+    void *frame_buf, *data_buf;
+    
     strm->frame_ts.u64 += strm->ts_inc;
     if (!strm->vid_cb.capture_cb)
 	return;
