@@ -1,4 +1,4 @@
-/* $Id: vid_codec_util.c 4854 2014-06-04 03:48:28Z nanang $ */
+/* $Id: vid_codec_util.c 5678 2017-11-01 04:55:29Z riza $ */
 /* 
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
@@ -39,12 +39,12 @@
 #define H264_STRICT_SDP_NEGO	    0
 
 /* Default frame rate, if not specified */
-#define DEFAULT_H264_FPS_NUM	    15
+#define DEFAULT_H264_FPS_NUM	    10
 #define DEFAULT_H264_FPS_DENUM	    1
 
 /* Default aspect ratio, if not specified */
-#define DEFAULT_H264_RATIO_NUM	    16
-#define DEFAULT_H264_RATIO_DENUM    9
+#define DEFAULT_H264_RATIO_NUM	    4
+#define DEFAULT_H264_RATIO_DENUM    3
 
 
 /* ITU resolution definition */
@@ -173,7 +173,7 @@ static unsigned fps_to_mpi(const pjmedia_ratio *fps)
     if (mpi < 1) mpi = 1;
 
     return mpi;
-};
+}
 
 PJ_DEF(pj_status_t) pjmedia_vid_codec_h263_apply_fmtp(
 				pjmedia_vid_codec_param *param)
@@ -399,7 +399,7 @@ PJ_DEF(pj_status_t) pjmedia_vid_codec_h264_parse_fmtp(
 		return status;
 	} else if (pj_stricmp(&fmtp->param[i].name, &PACKETIZATION_MODE)==0) {
 	    tmp = pj_strtoul(&fmtp->param[i].val);
-	    if (tmp >= 0 && tmp <= 2) 
+	    if (tmp <= 2) 
 		h264_fmtp->packetization_mode = (pj_uint8_t)tmp;
 	    else
 		return PJMEDIA_SDP_EINFMTP;
@@ -429,7 +429,6 @@ PJ_DEF(pj_status_t) pjmedia_vid_codec_h264_parse_fmtp(
 		const pj_uint8_t start_code[3] = {0, 0, 1};
 		char *p;
 		pj_uint8_t *nal;
-		pj_status_t status;
 
 		/* Find field separator ',' */
 		tmp_st = sps_st;
@@ -636,10 +635,14 @@ static pj_status_t find_highest_res(pjmedia_vid_codec_h264_fmtp *fmtp,
     max_fs = PJ_MIN(max_fs, fmtp->max_fs);
 
     /* Check if the specified ratio is using big numbers
-     * (not normalizable), override it with default ratio!
+     * (not normalizable), override it!
      */
-    if ((int)max_fs < asp_ratio.num * asp_ratio.denum)
-	asp_ratio = def_ratio;
+    if ((int)max_fs < asp_ratio.num * asp_ratio.denum) {
+        if ((int)max_fs >= def_ratio.num * def_ratio.denum)
+	    asp_ratio = def_ratio;
+	else
+	    asp_ratio.num = asp_ratio.denum = 1;
+    }
 
     /* Calculate the scale factor for size */
     scale = pj_isqrt(max_fs / asp_ratio.denum / asp_ratio.num);
